@@ -80,6 +80,8 @@ static init_func libfuncs[] = {
   {"script_tag", script_tag},
   {"vendor_version", nasl_vendor_version},
   {"update_table_driven_lsc_data", nasl_update_table_driven_lsc_data},
+  {"notus", nasl_notus},
+  {"notus_error", nasl_notus_error},
   {"get_preference", nasl_get_preference},
   {"safe_checks", safe_checks},
   {"get_script_oid", get_script_oid},
@@ -89,6 +91,7 @@ static init_func libfuncs[] = {
   {"get_kb_list", get_kb_list},
   {"get_host_kb_index", get_host_kb_index},
   {"security_message", security_message},
+  {"security_notus", security_notus},
   {"log_message", log_message},
   {"error_message", error_message2},
   {"open_sock_tcp", nasl_open_sock_tcp},
