@@ -2,6 +2,9 @@
 //
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
+// Until the Crypto scene is moving away from GenericArray
+#![allow(deprecated)]
+
 use thiserror::Error;
 
 // use crate::nasl::utils::combine_function_sets;
@@ -9,18 +12,20 @@ use crate::nasl::prelude::*;
 
 use crate::nasl::utils::{IntoFunctionSet, Register, StoredFunctionSet};
 
-mod aes_cbc;
 mod aes_ccm;
 mod aes_cmac;
 mod aes_ctr;
 mod aes_gcm;
 mod aes_gmac;
-mod bf_cbc;
+mod cbc;
 mod des;
+mod dh;
 mod hash;
 mod hmac;
 mod misc;
+mod ntlm;
 mod pem_to;
+mod prf;
 pub mod rc4;
 mod rsa;
 mod smb;
@@ -59,7 +64,7 @@ fn get_required_named_data<'a>(
     register: &'a Register,
     key: &'a str,
 ) -> Result<&'a [u8], ArgumentError> {
-    match register.nasl_value(key) {
+    match register.local_nasl_value(key) {
         Ok(NaslValue::Data(x)) => Ok(x.as_slice()),
         Ok(NaslValue::String(x)) => Ok(x.as_bytes()),
         Ok(x) => Err(ArgumentError::wrong_argument(
@@ -76,7 +81,7 @@ fn get_required_named_data<'a>(
 /// set to Some value. If it is false, no error will be returned but the Option can be either Some
 /// or None.
 fn get_optional_named_number(register: &Register, key: &str) -> Result<Option<i64>, ArgumentError> {
-    match register.nasl_value(key) {
+    match register.local_nasl_value(key) {
         Ok(NaslValue::Number(x)) => Ok(Some(*x)),
         Ok(x) => Err(ArgumentError::wrong_argument(
             key,
@@ -133,7 +138,7 @@ impl IntoFunctionSet for Cryptographic {
         let mut set = StoredFunctionSet::new(self);
         set.add_set(aes_ccm::AesCcm);
         set.add_set(hmac::HmacFns);
-        set.add_set(aes_cbc::AesCbc);
+        set.add_set(cbc::Cbc);
         set.add_set(aes_ctr::AesCtr);
         set.add_set(aes_gcm::AesGcmFns);
         set.add_set(aes_cmac::AesCmac);
@@ -141,10 +146,12 @@ impl IntoFunctionSet for Cryptographic {
         set.add_set(hash::Hash);
         set.add_set(des::Des);
         set.add_set(rsa::Rsa);
-        set.add_set(bf_cbc::BfCbc);
         set.add_set(pem_to::PemTo);
         set.add_set(smb::Smb);
         set.add_set(misc::Misc);
+        set.add_set(ntlm::Ntlm);
+        set.add_set(dh::Dh);
+        set.add_set(prf::Prf);
         set
     }
 }
