@@ -58,7 +58,7 @@ impl CipherHandlers {
     /// Closes a stream cipher.
     #[nasl_function]
     fn close_stream_cipher(&self, register: &Register) -> Result<NaslValue, FnError> {
-        let hd = match register.nasl_value("hd") {
+        let hd = match register.local_nasl_value("hd") {
             Ok(NaslValue::Number(x)) => *x as i32,
             _ => return Err(CryptographicError::Rc4("Handler ID not found".to_string()).into()),
         };
@@ -116,7 +116,7 @@ impl CipherHandlers {
             _ => return Err(CryptographicError::Rc4("Missing data argument".to_string()).into()),
         };
 
-        let hd = match register.nasl_value("hd") {
+        let hd = match register.local_nasl_value("hd") {
             Ok(NaslValue::Number(x)) => *x as i32,
             _ => 0,
         };
