@@ -2,18 +2,20 @@
 //
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
-mod aes_cbc;
 mod aes_ccm;
 mod aes_cmac;
 mod aes_ctr;
 mod aes_gcm;
-mod bf_cbc;
+mod cbc;
 mod des;
+mod dh;
 mod hash;
 mod helper;
 mod hmac;
 mod misc;
+mod ntlm;
 mod pem_to;
+mod prf;
 mod rc4;
 mod rsa;
 mod smb;
