@@ -290,6 +290,20 @@ fn vendor_version(context: &ScanCtx<'_>) -> Result<NaslValue, MiscError> {
     }
 }
 
+/// Are safe checks enabled ?
+#[nasl_function]
+fn safe_checks(context: &ScanCtx<'_>) -> bool {
+    context
+        .scan_preferences
+        .get_preference_bool("safe_checks")
+        .unwrap_or(false)
+}
+
+#[nasl_function]
+fn get_script_oid(context: &ScanCtx<'_>) -> Option<Vec<u8>> {
+    context.nvt().clone().map(|nvt| nvt.oid.into_bytes())
+}
+
 pub struct Misc;
 
 function_set! {
@@ -311,6 +325,8 @@ function_set! {
         gettimeofday,
         dump_ctxt,
         vendor_version,
+        safe_checks,
+        get_script_oid,
     )
 }
 
