@@ -16,6 +16,7 @@ mod isotime;
 mod knowledge_base;
 pub mod misc;
 pub mod network;
+mod snmp;
 
 mod preferences;
 #[cfg(feature = "nasl-builtin-raw-ip")]
@@ -25,6 +26,7 @@ mod report_functions;
 mod ssh;
 mod string;
 mod sys;
+mod wmi;
 
 #[cfg(test)]
 mod tests;
@@ -60,6 +62,8 @@ pub fn nasl_std_functions() -> Executor {
         .add_set(sys::Sys)
         .add_set(ssh::Ssh::default())
         .add_set(find_service::FindService)
+        .add_set(wmi::Wmi)
+        .add_set(snmp::Snmp)
         .add_set(cert::NaslCerts::default());
 
     #[cfg(feature = "nasl-builtin-raw-ip")]
