@@ -2,10 +2,10 @@
 //
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
-use russh::cipher;
-use russh_keys::key;
+use std::str::FromStr;
 
 use crate::nasl::{prelude::*, utils::function::StringOrData};
+use russh::{cipher, keys::Algorithm};
 
 /// A list of items which are represented as a
 /// NASL string which contains the items separated by
@@ -30,11 +30,11 @@ where
     }
 }
 
-impl<'a> FromNaslValue<'a> for key::Name {
+impl<'a> FromNaslValue<'a> for Algorithm {
     fn from_nasl_value(value: &'a NaslValue) -> Result<Self, FnError> {
         let s = String::from_nasl_value(value)?;
-        key::Name::try_from(&*s).map_err(|_| {
-            ArgumentError::WrongArgument(format!("Expected a valid SSH key type, found '{s}'"))
+        Algorithm::from_str(&s).map_err(|_| {
+            ArgumentError::WrongArgument(format!("Expected a valid SSH key algorithm, found '{s}'"))
                 .into()
         })
     }
