@@ -4,13 +4,16 @@
 
 //! Defines the context used within the interpreter and utilized by the builtin functions
 
+use greenbone_scanner_framework::models::{
+    AliveTestMethods, Port, PortRange, Protocol, ScanPreference,
+};
+use rand::seq::IndexedRandom;
 use tokio::sync::RwLock;
 
-use crate::models::{AliveTestMethods, Port, PortRange, Protocol, ScanPreference};
 use crate::nasl::builtin::{KBError, NaslSockets};
 use crate::nasl::syntax::Loader;
 use crate::nasl::{FromNaslValue, WithErrorInfo};
-use crate::scanner::preferences::preference::ScanPrefs;
+use crate::scanner::preferences::preference::{ScanPrefs, pref_is_true};
 use crate::storage::error::StorageError;
 use crate::storage::infisto::json::JsonStorage;
 use crate::storage::inmemory::InMemoryStorage;
@@ -18,13 +21,12 @@ use crate::storage::items::kb::{self, KbKey};
 use crate::storage::items::kb::{GetKbContextKey, KbContextKey, KbItem};
 use crate::storage::items::nvt::{Feed, FeedVersion, FileName, Nvt};
 use crate::storage::items::nvt::{NvtField, Oid};
-use crate::storage::items::result::{ResultContextKeyAll, ResultContextKeySingle, ResultItem};
+use crate::storage::items::result::{ResultContextKeySingle, ResultItem};
 use crate::storage::redis::{
     RedisAddAdvisory, RedisAddNvt, RedisGetNvt, RedisStorage, RedisWrapper,
 };
 use crate::storage::{self, ScanID};
 use crate::storage::{Dispatcher, Remover, Retriever};
-use rand::seq::SliceRandom;
 use std::collections::BTreeSet;
 use std::sync::MutexGuard;
 
@@ -236,9 +238,8 @@ pub trait ContextStorage:
     // results
     + Dispatcher<ScanID, Item = ResultItem>
     + Retriever<ResultContextKeySingle, Item = ResultItem>
-    + Retriever<ResultContextKeyAll, Item = Vec<ResultItem>>
-    + Remover<ResultContextKeySingle, Item = ResultItem>
-    + Remover<ResultContextKeyAll, Item = Vec<ResultItem>>
+    + Retriever<ScanID, Item = Vec<ResultItem>>
+    + Remover<ScanID, Item = Vec<ResultItem>>
     // nvt
     + Dispatcher<FileName, Item = Nvt>
     + Dispatcher<FeedVersion, Item = String>
@@ -363,7 +364,7 @@ impl<'a> ScanCtx<'a> {
         self.target.add_hostname(hostname, source);
     }
 
-    pub fn port_range(&self) -> PortRange {
+    fn port_range(&self) -> PortRange {
         // TODO Get this from the scan prefs
         PortRange {
             start: 0,
@@ -556,7 +557,7 @@ impl<'a> ScanCtx<'a> {
             .collect();
 
         let ret = if !ports.is_empty() {
-            *ports.choose(&mut rand::thread_rng()).unwrap()
+            *ports.choose(&mut rand::rng()).unwrap()
         } else if open21 {
             21
         } else if open80 {
@@ -568,10 +569,8 @@ impl<'a> ScanCtx<'a> {
     }
 
     fn get_preference_bool(&self, key: &str) -> Option<bool> {
-        self.scan_preferences
-            .iter()
-            .find(|x| x.id == key)
-            .map(|x| matches!(x.value.as_str(), "true" | "1" | "yes"))
+        let prefs = &self.scan_preferences;
+        pref_is_true(prefs, key)
     }
 
     pub fn get_port_state(&self, port: u16, protocol: Protocol) -> Result<bool, FnError> {
@@ -634,6 +633,7 @@ pub struct ScriptCtx {
     pub alive: bool,
     pub denial_port: Option<u16>,
     pub multicast_groups: Vec<JmpDesc>,
+    pub snmp_next: Option<String>,
 }
 
 pub struct ScanCtxBuilder<'a, P: AsRef<Path>> {
