@@ -6,6 +6,8 @@ use std::time::Duration;
 
 #[derive(Debug, Clone, serde::Serialize, serde::Deserialize)]
 #[serde(deny_unknown_fields)]
+// TODO: Actually use this configuration
+#[allow(dead_code)]
 struct Config {
     pub max_queued_scans: Option<usize>,
     pub max_running_scans: Option<usize>,
