@@ -2,6 +2,7 @@
 //
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
+use super::resources::check::Checker;
 use super::{
     cmd,
     error::OpenvasError,
@@ -9,17 +10,9 @@ use super::{
     pref_handler::PreferenceHandler,
     result_collector::ResultHelper,
 };
-use crate::models::{
-    HostInfoBuilder, Phase, Status,
-    scanner::{
-        Error as ScanError, ScanDeleter, ScanResultFetcher, ScanResultKind, ScanResults,
-        ScanStarter, ScanStopper,
-    },
-};
-use crate::{
-    models::{self, Scan, resources::check::Checker},
-    storage::redis::{NameSpaceSelector, RedisCtx},
-};
+use greenbone_scanner_framework::models::{self, HostInfo, Phase, Scan, Status};
+
+use crate::storage::redis::{NameSpaceSelector, RedisCtx};
 use async_trait::async_trait;
 use std::{
     collections::HashMap,
@@ -38,6 +31,10 @@ pub struct Scanner {
     resource_checker: Option<Checker>,
     default_scanner_preferences: Vec<models::ScanPreferenceInformation>,
 }
+use crate::scanner::{
+    Error as ScanError, ScanDeleter, ScanResultFetcher, ScanResultKind, ScanResults, ScanStarter,
+    ScanStopper,
+};
 
 impl From<OpenvasError> for ScanError {
     fn from(value: OpenvasError) -> Self {
@@ -141,7 +138,7 @@ impl Scanner {
         let nvtcache = Arc::new(Mutex::new(
             match RedisCtx::open(&self.redis_socket, &[NameSpaceSelector::Key("nvticache")]) {
                 Ok(x) => x,
-                Err(e) => return Err(ScanError::Connection(format!("{e}"))),
+                Err(e) => return Err(ScanError::Connection(format!("nvticache: {e}"))),
             },
         ));
         Ok(RedisHelper::<RedisCtx>::new(nvtcache, kbctx))
@@ -186,7 +183,7 @@ impl ScanStarter for Scanner {
         return Ok(());
     }
 
-    async fn can_start_scan(&self, _: &Scan) -> bool {
+    async fn can_start_scan(&self) -> bool {
         self.resource_checker
             .as_ref()
             .map(|v| v.in_boundaries())
@@ -247,19 +244,13 @@ impl ScanDeleter for Scanner {
 
         let mut redis_help = self.create_redis_connector(Some(dbid))?;
         let mut ov_results = ResultHelper::init(&mut redis_help);
-        ov_results
+        let status = ov_results
             .collect_scan_status(scan_id.to_string())
             .await
             .map_err(|e| ScanError::Unexpected(e.to_string()))?;
-
-        let mut scan_status = Phase::Running;
-        if let Ok(res) = Arc::as_ref(&ov_results.results).lock() {
-            scan_status = OpenvasPhase::from_str(&res.scan_status)
-                .map_err(|_| {
-                    ScanError::Unexpected(format!("Invalid Phase status {}", res.scan_status))
-                })?
-                .into();
-        }
+        let scan_status = OpenvasPhase::from_str(&status)
+            .map_err(|_| ScanError::Unexpected(format!("Invalid Phase status {}", status)))?
+            .into();
 
         match scan_status {
             Phase::Running => {
@@ -303,103 +294,97 @@ impl ScanResultFetcher for Scanner {
         let mut redis_help = self.create_redis_connector(Some(dbid))?;
         let mut ov_results = ResultHelper::init(&mut redis_help);
 
-        ov_results
+        //TODO: error handling
+        let mut all_results = ov_results
             .collect_results()
             .await
             .map_err(|e| ScanError::Unexpected(e.to_string()))?;
-        ov_results
-            .collect_host_status()
-            .await
-            .map_err(|e| ScanError::Unexpected(e.to_string()))?;
-        ov_results
+        all_results.extend(
+            ov_results
+                .collect_host_status()
+                .await
+                .map_err(|e| ScanError::Unexpected(e.to_string()))?,
+        );
+        all_results.scan_status = ov_results
             .collect_scan_status(scan_id.to_string())
             .await
             .map_err(|e| ScanError::Unexpected(e.to_string()))?;
-
-        match Arc::as_ref(&ov_results.results).lock() {
-            Ok(all_results) => {
-                let hosts_info = HostInfoBuilder {
-                    all: all_results.count_total as u64,
-                    excluded: all_results.count_excluded as u64,
-                    dead: all_results.count_dead as u64,
-                    alive: all_results.count_alive as u64,
-                    queued: 0,
-                    finished: all_results.count_alive as u64,
-                    scanning: Some(all_results.host_status.clone()),
-                }
-                .build();
-
-                let status: Phase = OpenvasPhase::from_str(&all_results.scan_status)
-                    .map_err(|_| {
-                        ScanError::Unexpected(format!(
-                            "Invalid Phase status {}",
-                            all_results.scan_status
-                        ))
-                    })?
-                    .into();
-                let start_time = match status {
-                    Phase::Running => Some(
-                        SystemTime::now()
-                            .duration_since(SystemTime::UNIX_EPOCH)
-                            .expect("Valid timestamp for start scan")
-                            .as_secs(),
-                    ),
-                    _ => None,
-                };
-                let end_time = match status {
-                    Phase::Failed | Phase::Stopped | Phase::Succeeded => Some(
-                        SystemTime::now()
-                            .duration_since(SystemTime::UNIX_EPOCH)
-                            .expect("Valid timestamp for start scan")
-                            .as_secs(),
-                    ),
-                    _ => None,
-                };
-
-                let st = Status {
-                    start_time,
-                    end_time,
-                    status: status.clone(),
-                    host_info: Some(hosts_info),
-                };
-
-                let mut scan_res = ScanResults {
-                    id: scan_id.to_string(),
-                    status: st,
-                    results: all_results
-                        .results
-                        .iter()
-                        .map(|r| models::Result::from(r).clone())
-                        .collect(),
-                };
-                // If the scan finished, release. Openvas "finished" status is translated todo
-                // Succeeded. It is necessary to read the exit code to know if it failed.
-                if status == Phase::Succeeded {
-                    let mut scan = match self.remove_running(scan_id) {
-                        Some(scan) => scan.0,
-                        None => return Err(OpenvasError::ScanNotFound(scan_id.to_string()).into()),
-                    };
-
-                    // Read openvas scanner exit code and if failed, reset the status to Failed.
-                    let exit_status = scan.wait().map_err(OpenvasError::CmdError)?;
-                    if let Some(code) = exit_status.code()
-                        && code != 0
-                    {
-                        scan_res.status.status = Phase::Failed;
-                        scan_res.status.start_time = scan_res.status.end_time;
-                        scan_res.status.host_info = None;
-                    }
-
-                    redis_help
-                        .release()
-                        .map_err(|e| ScanError::Unexpected(e.to_string()))?;
-                    self.running.lock().unwrap().remove(scan_id);
-                }
-
-                return Ok(scan_res);
-            }
-            Err(_) => return Err(OpenvasError::ScanNotFound(scan_id.to_string()).into()),
+        let hosts_info = HostInfo {
+            all: all_results.count_total as u64,
+            excluded: all_results.count_excluded as u64,
+            dead: all_results.count_dead as u64,
+            alive: all_results.count_alive as u64,
+            queued: 0,
+            finished: all_results.count_alive as u64,
+            scanning: Some(all_results.host_status.clone()),
+            ..Default::default()
         };
+
+        let status: Phase = OpenvasPhase::from_str(&all_results.scan_status)
+            .map_err(|_| {
+                ScanError::Unexpected(format!("Invalid Phase status {}", all_results.scan_status))
+            })?
+            .into();
+        let start_time = match status {
+            Phase::Running => Some(
+                SystemTime::now()
+                    .duration_since(SystemTime::UNIX_EPOCH)
+                    .expect("Valid timestamp for start scan")
+                    .as_secs(),
+            ),
+            _ => None,
+        };
+        let end_time = match status {
+            Phase::Failed | Phase::Stopped | Phase::Succeeded => Some(
+                SystemTime::now()
+                    .duration_since(SystemTime::UNIX_EPOCH)
+                    .expect("Valid timestamp for start scan")
+                    .as_secs(),
+            ),
+            _ => None,
+        };
+
+        let st = Status {
+            start_time,
+            end_time,
+            status: status.clone(),
+            host_info: Some(hosts_info),
+        };
+
+        let mut scan_res = ScanResults {
+            id: scan_id.to_string(),
+            status: st,
+            results: all_results
+                .results
+                .iter()
+                .map(|r| models::Result::from(r).clone())
+                .collect(),
+        };
+        // If the scan finished, release. Openvas "finished" status is translated into
+        // Succeeded. It is necessary to read the exit code to know if it failed.
+        if status == Phase::Succeeded {
+            let mut scan = match self.remove_running(scan_id) {
+                Some(scan) => scan.0,
+                None => return Err(OpenvasError::ScanNotFound(scan_id.to_string()).into()),
+            };
+
+            // Read openvas scanner exit code and if failed, reset the status to Failed.
+            let exit_status = scan.wait().map_err(OpenvasError::CmdError)?;
+            if let Some(code) = exit_status.code()
+                && code != 0
+            {
+                scan_res.status.status = Phase::Failed;
+                scan_res.status.start_time = scan_res.status.end_time;
+                scan_res.status.host_info = None;
+            }
+
+            redis_help
+                .release()
+                .map_err(|e| ScanError::Unexpected(e.to_string()))?;
+            self.running.lock().unwrap().remove(scan_id);
+        }
+
+        return Ok(scan_res);
     }
 
     fn scan_result_status_kind(&self) -> ScanResultKind {
