@@ -2,9 +2,10 @@
 //
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
-use crate::models;
+use crate::notus::advisories::VulnerabilityData;
 
-pub type NotusAdvisory = models::VulnerabilityData;
+// why????
+pub type NotusAdvisory = VulnerabilityData;
 
 #[derive(Clone)]
 pub struct NotusCache;
