@@ -12,9 +12,8 @@ use super::dberror::RedisStorageResult;
 use itertools::Itertools;
 use redis::*;
 
-use crate::models;
-use crate::models::Vulnerability;
-
+use crate::notus::advisories::Vulnerability;
+use crate::notus::advisories::VulnerabilityData;
 use crate::storage::StorageError;
 use crate::storage::items::nvt::ACT;
 use crate::storage::items::nvt::Nvt;
@@ -138,7 +137,7 @@ impl NameSpaceSelector {
             NameSpaceSelector::Free => {
                 Self::select_namespace(kb, 0)?;
                 for dbi in 1..max_db {
-                    match kb.hset_nx(DB_INDEX, dbi, 1) {
+                    match redis::Commands::hset_nx(kb, DB_INDEX, dbi, 1) {
                         Ok(1) => {
                             Self::select_namespace(kb, dbi)?;
                             return Ok(dbi);
@@ -152,7 +151,7 @@ impl NameSpaceSelector {
             NameSpaceSelector::Key(key) => {
                 for dbi in 1..max_db {
                     Self::select_namespace(kb, dbi)?;
-                    match kb.exists(key) {
+                    match redis::Commands::exists(kb, key) {
                         Ok(1) => return Ok(dbi),
                         Ok(_) => {}
                         Err(err) => return Err(err.into()),
@@ -184,63 +183,55 @@ impl RedisWrapper for RedisCtx {
     ///Wrapper function to avoid accessing kb member directly.
     #[inline(always)]
     fn rpush<T: ToRedisArgs>(&mut self, key: &str, val: T) -> RedisStorageResult<()> {
-        self.kb
-            .as_mut()
-            .expect("Valid redis connection")
-            .rpush(key, val)
-            .map_err(|e| e.into())
+        redis::Commands::rpush(self.kb.as_mut().expect("Valid redis connection"), key, val)
+            .map_err(DbError::from)
     }
 
     ///Wrapper function to avoid accessing kb member directly.
     #[inline(always)]
     fn lpush<T: ToRedisArgs>(&mut self, key: &str, val: T) -> RedisStorageResult<()> {
-        self.kb
-            .as_mut()
-            .expect("Valid redis connection")
-            .lpush(key, val)
-            .map_err(|e| e.into())
+        redis::Commands::lpush(self.kb.as_mut().expect("Valid redis connection"), key, val)
+            .map_err(DbError::from)
     }
 
     ///Wrapper function to avoid accessing kb member directly.
     #[inline(always)]
     fn del(&mut self, key: &str) -> RedisStorageResult<()> {
-        self.kb
-            .as_mut()
-            .expect("Valid redis connection")
-            .del(key)
-            .map_err(|e| e.into())
+        redis::Commands::del(self.kb.as_mut().expect("Valid redis connection"), key)
+            .map_err(DbError::from)
     }
 
     ///Wrapper function to avoid accessing kb member directly.
     #[inline(always)]
     fn lindex(&mut self, key: &str, index: isize) -> RedisStorageResult<String> {
-        let ret: RedisValueHandler = self
-            .kb
-            .as_mut()
-            .expect("Valid redis connection")
-            .lindex(key, index)?;
+        let ret: RedisValueHandler = redis::Commands::lindex(
+            self.kb.as_mut().expect("Valid redis connection"),
+            key,
+            index,
+        )
+        .map_err(DbError::from)?;
         Ok(ret.v)
     }
 
     ///Wrapper function to avoid accessing kb member directly.
     #[inline(always)]
     fn lrange(&mut self, key: &str, start: isize, end: isize) -> RedisStorageResult<Vec<String>> {
-        let ret = self
-            .kb
-            .as_mut()
-            .expect("Valid redis connection")
-            .lrange(key, start, end)?;
+        let ret = redis::Commands::lrange(
+            self.kb.as_mut().expect("Valid redis connection"),
+            key,
+            start,
+            end,
+        )
+        .map_err(DbError::from)?;
         Ok(ret)
     }
 
     ///Wrapper function to avoid accessing kb member directly.
     #[inline(always)]
     fn keys(&mut self, pattern: &str) -> RedisStorageResult<Vec<String>> {
-        let ret: Vec<String> = self
-            .kb
-            .as_mut()
-            .expect("Valid redis connection")
-            .keys(pattern)?;
+        let ret: Vec<String> =
+            redis::Commands::keys(self.kb.as_mut().expect("Valid redis connection"), pattern)
+                .map_err(DbError::from)?;
         Ok(ret)
     }
 
@@ -271,10 +262,7 @@ pub trait RedisAddAdvisory: RedisWrapper {
     /// - 'nvt:<OID>': stores the general metadata ordered following the KbNvtPos indexes
     /// - 'oid:<OID>:prefs': stores the plugins preferences, including the script_timeout
     ///   (which is especial and uses preferences id 0)
-    fn redis_add_advisory(
-        &mut self,
-        adv: Option<models::VulnerabilityData>,
-    ) -> RedisStorageResult<()> {
+    fn redis_add_advisory(&mut self, adv: Option<VulnerabilityData>) -> RedisStorageResult<()> {
         match adv {
             Some(data) => {
                 let key = format!("internal/notus/advisories/{}", &data.adv.oid);
@@ -611,12 +599,4 @@ impl RedisCtx {
         self.release_namespace()?;
         Ok(())
     }
-
-    /// Clean up the namespace.
-    pub fn flush_namespace(&mut self) -> RedisStorageResult<()> {
-        Cmd::new()
-            .arg("FLUSHDB")
-            .query::<()>(&mut self.kb.as_mut().expect("Valid redis connection"))?;
-        Ok(())
-    }
 }
